/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.sql.Timestamp;

import org.apache.juddi.datastore.dht.datatype.AuthToken;
import org.apache.juddi.datatype.publisher.Publisher;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class AuthTokenTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(AuthTokenTable.class);

	static {

	}

	/**
	 * Insert new row into the AUTH_TOKEN table.
	 * 
	 * @param authToken
	 * @param publisher
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String authToken, Publisher publisher,
			DHTHandler connection) {

		AuthToken tmp = new AuthToken(authToken, publisher);
		try {
			connection.insert(authToken	+ " authToken", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select one row from the AUTH_TOKEN table.
	 * 
	 * @param authToken
	 * @param connection
	 *            DHT connection
	 * @return Publisher The publisher's info
	 */
	public static Publisher selectPublisher(String authToken,
			DHTHandler connection) {

		Publisher publisher = null;
		try {
			publisher = ((AuthToken)(connection.retrieve(authToken + " authToken"))).getPublisher();
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	
		return publisher;

	}

	/**
	 * Delete row from the AUTH_TOKEN table.
	 * 
	 * @param authToken
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String authToken, DHTHandler connection) {
		try {
			connection.remove("", authToken + " authToken");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	public static void invalidate(String token, DHTHandler connection) {
		Timestamp timestamp = new Timestamp(System.currentTimeMillis());
		AuthToken tmp = null;
		try {
			tmp = (AuthToken) connection.retrieve(token + " authToken");
			tmp.setLastused(timestamp);
			tmp.setNumberofuses(tmp.getNumberofuses() + 1);
			tmp.setTokenstate(0);
			connection.insert(token + " authToken", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}

	public static void touch(String token, DHTHandler connection) {
		Timestamp timestamp = new Timestamp(System.currentTimeMillis());
		AuthToken tmp = null;
		try {
			tmp = (AuthToken) connection.retrieve(token + " authToken");
			tmp.setLastused(timestamp);
			tmp.setNumberofuses(tmp.getNumberofuses() + 1);
			connection.insert(token + " authToken", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	public static long selectTokenState(String token, DHTHandler connection) {
		AuthToken a = null;
		try {
			a= (AuthToken) connection.retrieve(token + " authToken");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return a.getTokenstate();

	}

	public static long selectLastUsed(String token, DHTHandler connection) {
		AuthToken a = null;
		try {
			a= (AuthToken) connection.retrieve(token + " authToken");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return a.getLastused();
	}

}
