/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.BindingCategory;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class BindingCategoryTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(BindingCategoryTable.class);

	static {

	}

	/**
	 * Insert new row into the BINDING_CATEGORY table.
	 * 
	 * @param bindingKey
	 *            String to the parent BindingTemplate object.
	 * @param keyRefs
	 *            A Vector of KeyedReference instances to insert.
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String bindingKey, Vector keyRefs,
			DHTHandler connection) {

		BindingCategory tmp = new BindingCategory(bindingKey, keyRefs);
		try {
			connection.insert(bindingKey + " bindingcategory", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the BINDING_CATEGORY table for a given BindingKey.
	 * 
	 * @param bindingKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String bindingKey, DHTHandler connection) {

		BindingCategory tmp = null;

		try {
			tmp = (BindingCategory) connection.retrieve(bindingKey + " bindingcategory");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return tmp.getKeyRefs();

	}

	/**
	 * Delete multiple rows from the BINDING_CATEGORY table that are assigned to
	 * the BindingKey specified.
	 * 
	 * @param bindingKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String bindingKey, DHTHandler connection) {
		try {
			connection.remove("", bindingKey + " bindingcategory");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
