/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.BindingDesc;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class BindingDescTable {
	// private reference to the jUDDI logger
	// //private static Log log = LogFactory.getLog(BindingDescTable.class);

	static {

	}

	/**
	 * Insert new row into the BINDING_DESCR table.
	 * 
	 * @param bindingKey
	 *            String to the BusinessEntity object that owns the Description
	 *            to be inserted
	 * @param descList
	 *            Enumeration of Description objects to be inserted
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String bindingKey, Vector descList,
			DHTHandler connection) {
		if ((descList == null) || (descList.size() == 0))
			return; // everything is valid but no elements to insert

		BindingDesc tmp = new BindingDesc(bindingKey, descList);
		try {
			connection.insert(bindingKey + " bindingdesc", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the BINDING_DESCR table for a given BusinessKey.
	 * 
	 * @param bindingKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String bindingKey, DHTHandler connection) {
		BindingDesc tmp = null;

		try {
			tmp = (BindingDesc) connection.retrieve(bindingKey + " bindingdesc");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		
		return tmp.getDescList();

	}

	/**
	 * Delete multiple rows from the BINDING_DESCR table that are assigned to
	 * the BusinessKey specified.
	 * 
	 * @param bindingKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String bindingKey, DHTHandler connection) {
		try {
			connection.remove("", bindingKey + " bindingdesc");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
