/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Iterator;
import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.BusinessEntity;
import org.apache.juddi.datatype.binding.BindingTemplate;

import bunshin.util.ResultSortedQueue;
import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class BindingTemplateTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(BindingTemplateTable.class);

	static {

	}

	/**
	 * Insert new row into the BINDING_TEMPLATE table.
	 * 
	 * @param binding
	 *            Binding Template object holding values to be inserted
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(BindingTemplate binding, DHTHandler connection) {
		try {
			connection.insert(binding.getBindingKey() + " "
					+ binding.getServiceKey() + " bindingtemplate", binding
					.getBindingKey()
					+ " bindingtemplate", binding);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Delete row from the BINDING_TEMPLATE table.
	 * 
	 * @param bindingKey
	 *            primary key value
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String bindingKey, DHTHandler connection) {
		try {
			connection.remove("", bindingKey + " bindingtemplate");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select one row from the BINDING_TEMPLATE table.
	 * 
	 * @param bindingKey
	 *            primary key value
	 * @param connection
	 *            DHT connection
	 */
	public static BindingTemplate select(String bindingKey,
			DHTHandler connection) {
		BindingTemplate tmp = null;

		try {
			tmp = (BindingTemplate) connection.retrieve(bindingKey + " bindingtemplate");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return tmp;

	}

	/**
	 * Select all rows from the business_service table for a given BusinessKey.
	 * 
	 * @param serviceKey
	 *            ServiceKey
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector selectByServiceKey(String serviceKey,
			DHTHandler connection) {
		Vector bindList = new Vector();

		ResultSortedQueue tmp = null;

		try {
			tmp = connection.query(serviceKey + " bindingtemplate");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		Iterator it = tmp.iterator();
		while (it.hasNext()) {
			bindList.add((BindingTemplate) it.next());
		}
		return bindList;

	}

	/**
	 * Delete multiple rows from the BINDING_TEMPLATE table that are assigned to
	 * the BusinessKey specified.
	 * 
	 * @param serviceKey
	 *            ServiceKey
	 * @param connection
	 *            DHT connection
	 */
	public static void deleteByServiceKey(String serviceKey,
			DHTHandler connection) {

		ResultSortedQueue tmp = null;

		try {
			tmp = connection.query(serviceKey + " bindingtemplate");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		Iterator it = tmp.iterator();
		while (it.hasNext()) {
			try {
				connection.remove(serviceKey + " bindingtemplate",
						((BindingTemplate) it.next()).getBindingKey()
								+ " bindingtemplate");
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

	}

	/**
	 * Verify that 'authorizedName' has the authority to update or delete
	 * BindingTemplate identified by the bindingKey parameter
	 * 
	 * @param bindingKey
	 * @param publisherID
	 * @param DHT
	 *            connection
	 */
	public static boolean verifyOwnership(String bindingKey,
			String publisherID, DHTHandler connection) {
		if ((bindingKey == null) || (publisherID == null))
			return false;

		boolean authorized = false;
		ResultSortedQueue tmp = null;
		String bk = null, sk = null;

		/*
		 * "SELECT * " "FROM BUSINESS_ENTITY e, BUSINESS_SERVICE s,
		 * BINDING_TEMPLATE t " "WHERE s.SERVICE_KEY = t.SERVICE_KEY " "AND
		 * e.BUSINESS_KEY = s.BUSINESS_KEY " "AND t.BINDING_KEY=? " "AND
		 * e.PUBLISHER_ID=?"
		 */

		try {
			tmp = connection.query(publisherID + " businessentity");
			BusinessEntity e = (BusinessEntity) tmp.iterator().next();
			bk = e.getBusiness().getBusinessKey();
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} // e
		try {
			BindingTemplate t = (BindingTemplate)connection.retrieve(bindingKey + " bindingtemplate");
			sk = t.getServiceKey();
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} // t
		try {
			connection.query(sk + " " + bk + " businessservice");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} // s

		return authorized;

	}
}