/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Iterator;
import java.util.Vector;

import org.apache.juddi.datatype.service.BusinessService;

import bunshin.util.ResultSortedQueue;
import dermi.DHTHandler;
import dermi.core.Id;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class BusinessServiceTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(BusinessServiceTable.class);

	static {

	}

	/**
	 * Insert new row into the BUSINESS_ENTITIES table.
	 * 
	 * @param service
	 *            object holding values to be inserted
	 * @param connection
	 *            DHT connection
	 * 
	 */
	public static void insert(BusinessService service, DHTHandler connection) {
		try {
			connection.insert(service.getServiceKey() + " "
					+ service.getBusinessKey() + " businessservice", service
					.getServiceKey()
					+ " businessservice", service);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Delete row from the BUSINESS_SERVICE table.
	 * 
	 * @param serviceKey
	 *            Primary key value
	 * @param connection
	 *            DHT connection
	 * 
	 */
	public static void delete(String serviceKey, DHTHandler connection) {
		try {
			connection.remove("", serviceKey + " businessservice");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select one row from the BUSINESS_SERVICE table.
	 * 
	 * @param serviceKey
	 *            primary key value
	 * @param connection
	 *            DHT connection
	 * 
	 */
	public static BusinessService select(String serviceKey,
			DHTHandler connection) {
		BusinessService service = null;

		try {
			service = (BusinessService)connection.retrieve(serviceKey + " businessservice");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}


		return service;

	}

	/**
	 * Delete multiple rows from the BUSINESS_SERVICE table that are assigned to
	 * the BusinessKey specified.
	 * 
	 * @param businessKey
	 *            BusinessKey
	 * @param connection
	 *            DHT connection
	 * 
	 */
	public static void deleteByBusinessKey(String businessKey,
			DHTHandler connection) {

		ResultSortedQueue tmp = null;

		try {
			tmp = connection.query(businessKey + " businessservice");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		Iterator it = tmp.iterator();
		while (it.hasNext()) {
			try {
				connection.remove(businessKey + " businessservice",
						(((BusinessService) connection.retrieve((Id)it.next()))).getServiceKey()
								+ " businessservice");
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

	}

	/**
	 * Select all rows from the business_service table for a given BusinessKey.
	 * 
	 * @param businessKey
	 *            BusinessKey
	 * @param connection
	 *            DHT connection
	 * 
	 */
	@SuppressWarnings("unchecked")
	public static Vector selectByBusinessKey(String businessKey,
			DHTHandler connection)

	{
		Vector serviceList = new Vector();
		ResultSortedQueue tmp = null;

		try {
			tmp = connection.query(businessKey + " businessservice");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		Iterator it = tmp.iterator();
		while (it.hasNext()) {
			try {
				serviceList.add((BusinessService) connection.retrieve((Id)it.next()));
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

		return serviceList;

	}

	/**
	 * Verify that 'authorizedName' has the authority to update or delete
	 * BusinessService identified by the serviceKey parameter
	 * 
	 * @param serviceKey
	 * @param publisherID
	 * @param DHT
	 *            connection
	 * 
	 */
	public static boolean verifyOwnership(String serviceKey,
			String publisherID, DHTHandler connection)

	{
		if ((serviceKey == null) || (publisherID == null))
			return false;

		boolean authorized = false;
		ResultSortedQueue tmp = null;

		try {
			tmp = connection.query(serviceKey + " " + publisherID
					+ " businessservice");
			authorized = tmp.iterator().hasNext();
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return authorized;
	}
}
