/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.ServiceDesc;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class ServiceDescTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(ServiceDescTable.class);

	static {

	}

	/**
	 * Insert new row into the SERVICE_DESCR table.
	 * 
	 * @param serviceKey
	 *            String to the BusinessEntity object that owns the Description
	 *            to be inserted
	 * @param descList
	 *            Vector of Description objects holding values to be inserted
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String serviceKey, Vector descList,
			DHTHandler connection) {
		if ((descList == null) || (descList.size() == 0))
			return; // everything is valid but no elements to insert

		ServiceDesc tmp = new ServiceDesc(serviceKey, descList);
		try {
			connection.insert(serviceKey+ " servicedesc", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the SERVICE_DESCR table for a given BusinessKey.
	 * 
	 * @param serviceKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String serviceKey, DHTHandler connection) {

		ServiceDesc tmp = null;

		try {
			tmp = (ServiceDesc)connection.retrieve(serviceKey + " servicedesc");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		return tmp.getDescList();

	}

	/**
	 * Delete multiple rows from the SERVICE_DESCR table that are assigned to
	 * the BusinessKey specified.
	 * 
	 * @param serviceKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String serviceKey, DHTHandler connection) {
		try {
			connection.remove("", serviceKey + " servicedesc");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
