/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Iterator;
import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.ServiceName;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class ServiceNameTable {

	static {

	}

	/**
	 * Insert new row into the SERVICE_NAME table.
	 * 
	 * @param serviceKey
	 *            String to the BusinessEntity object that owns the Contact to
	 *            be inserted
	 * @param nameList
	 *            Vector of Name objects holding values to be inserted
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String serviceKey, Vector nameList,
			DHTHandler connection) {
		if ((nameList == null) || (nameList.size() == 0))
			return; // everything is valid but no elements to insert

		ServiceName tmp = new ServiceName(serviceKey, nameList);
		try {
			
			/*
			 * Aadimos la lista de nombres ya que es la nica manera de
			 * seguir el estandar uddi, sin un recorrido por todos los nodos.
			 */
			
			String txt="";
			Iterator it = nameList.iterator();
			while(it.hasNext()){
				txt+=" " + (String)it.next();
			}
			System.out.println("insert: " + serviceKey + txt + " servicename");
			connection.insert(txt + " servicename", serviceKey
					+ " servicename", tmp);
			
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the SERVICE_NAME table for a given ServiceKey.
	 * 
	 * @param serviceKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String serviceKey, DHTHandler connection) {

		ServiceName tmp = null;

		try {
			tmp =(ServiceName) connection.retrieve(serviceKey + " servicename");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return tmp.getNameList();

	}

	/**
	 * Delete multiple rows from the SERVICE_NAME table that are assigned to the
	 * ServiceKey specified.
	 * 
	 * @param serviceKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String serviceKey, DHTHandler connection) {
		try {
			connection.remove("", serviceKey + " servicename");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
