/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.TModelDesc;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class TModelDescTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(TModelDescTable.class);

	static {

	}

	/**
	 * Insert new row into the TMODEL_DESCR table.
	 * 
	 * @param tModelKey
	 *            BusinessKey to the BusinessEntity object that owns the
	 *            Description to be inserted
	 * @param descList
	 *            Vector of Description objects holding values to be inserted
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String tModelKey, Vector descList,
			DHTHandler connection) {
		if ((descList == null) || (descList.size() == 0))
			return; // everything is valid but no elements to insert

		TModelDesc tmp = new TModelDesc(tModelKey, descList);
		try {
			connection.insert(tModelKey	+ " tmodeldesc", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the TMODEL_DESCR table for a given TModelKey.
	 * 
	 * @param tModelKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String tModelKey, DHTHandler connection) {

		TModelDesc tmp = null;

		try {
			tmp =(TModelDesc) connection.retrieve(tModelKey + " tmodeldesc");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		
		return tmp.getDescList();

	}

	/**
	 * Delete multiple rows from the TMODEL_DESCR table that are assigned to the
	 * TModelKey specified.
	 * 
	 * @param tModelKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String tModelKey, DHTHandler connection) {
		try {
			connection.remove("", tModelKey + " tmodeldesc");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
