/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.TModelIdentifier;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class TModelIdentifierTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(TModelIdentifierTable.class);

	static {

	}

	/**
	 * Insert new row into the TMODEL_IDENTIFIER table.
	 * 
	 * @param tModelKey
	 *            String to the parent TModelEntity object.
	 * @param keyRefs
	 *            A Vector of KeyedReference instances to insert.
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String tModelKey, Vector keyRefs,
			DHTHandler connection) {

		TModelIdentifier tmp = new TModelIdentifier(tModelKey, keyRefs);
		try {
			connection.insert(tModelKey	+ " tmodelidentifier", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the TMODEL_IDENTIFIER table for a given TModelKey.
	 * 
	 * @param tModelKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String tModelKey, DHTHandler connection) {
		TModelIdentifier tmp = null;

		try {
			tmp = (TModelIdentifier)connection.retrieve(tModelKey + " tmodelidentifier");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return tmp.getKeyRefs();

	}

	/**
	 * Delete multiple rows from the TMODEL_IDENTIFIER table that are assigned
	 * to the TModelKey specified.
	 * 
	 * @param tModelKey
	 *            String
	 * @param connection
	 *            JDBC connection
	 */
	public static void delete(String tModelKey, DHTHandler connection) {
		try {
			connection.remove("", tModelKey + " tmodelidentifier");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
