/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.handler;

import java.util.Vector;

import org.apache.juddi.datatype.RegistryObject;
import org.apache.juddi.datatype.response.BusinessInfo;
import org.apache.juddi.datatype.response.BusinessInfos;
import org.apache.juddi.util.xml.XMLUtils;
import org.w3c.dom.Element;

/**
 * "Knows about the creation and populating of BusinessInfos objects. Returns
 * BusinessInfos."
 * 
 * @author Steve Viens (sviens@apache.org)
 */
public class BusinessInfosHandler extends AbstractHandler {
	public static final String TAG_NAME = "businessInfos";

	private HandlerMaker maker = null;

	protected BusinessInfosHandler(HandlerMaker maker) {
		this.maker = maker;
	}

	public RegistryObject unmarshal(Element element) {
		BusinessInfos obj = new BusinessInfos();
		Vector nodeList = null;
		AbstractHandler handler = null;

		// Attributes
		// {none}

		// Text Node Value
		// {none}

		// Child Elements
		nodeList = XMLUtils.getChildElementsByTagName(element,
				BusinessInfoHandler.TAG_NAME);
		for (int i = 0; i < nodeList.size(); i++) {
			handler = maker.lookup(BusinessInfoHandler.TAG_NAME);
			obj.addBusinessInfo((BusinessInfo) handler
					.unmarshal((Element) nodeList.elementAt(i)));
		}

		return obj;
	}

	public void marshal(RegistryObject object, Element parent) {
		BusinessInfos infos = (BusinessInfos) object;
		Element element = parent.getOwnerDocument().createElementNS(null,
				TAG_NAME);
		AbstractHandler handler = null;

		Vector vector = infos.getBusinessInfoVector();
		if ((vector != null) && (vector.size() > 0)) {
			handler = maker.lookup(BusinessInfoHandler.TAG_NAME);
			for (int i = 0; i < vector.size(); i++)
				handler.marshal((BusinessInfo) vector.elementAt(i), element);
		}

		parent.appendChild(element);
	}

	/** ************************************************************************ */
	/** *************************** TEST DRIVER ******************************** */
	/** ************************************************************************ */

	public static void main(String args[]) throws Exception {
	}
}