/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.handler;

import java.util.Vector;

import org.apache.juddi.datatype.RegistryObject;
import org.apache.juddi.datatype.request.AuthInfo;
import org.apache.juddi.datatype.request.SaveSubscription;
import org.apache.juddi.datatype.subscription.Subscription;
import org.apache.juddi.util.xml.XMLUtils;
import org.w3c.dom.Element;

/**
 * @author Steve Viens (sviens@apache.org)
 */
public class SaveSubscriptionHandler extends AbstractHandler {
	public static final String TAG_NAME = "save_subscription";

	private HandlerMaker maker = null;

	protected SaveSubscriptionHandler(HandlerMaker maker) {
		this.maker = maker;
	}

	public RegistryObject unmarshal(Element element) {
		SaveSubscription obj = new SaveSubscription();
		Vector nodeList = null;
		AbstractHandler handler = null;

		// Attributes
		String generic = element.getAttribute("generic");
		if ((generic != null && (generic.trim().length() > 0)))
			obj.setGeneric(generic);

		// Text Node Value
		// {none}

		// Child Elements
		nodeList = XMLUtils.getChildElementsByTagName(element,
				AuthInfoHandler.TAG_NAME);
		if (nodeList.size() > 0) {
			handler = maker.lookup(AuthInfoHandler.TAG_NAME);
			obj.setAuthInfo((AuthInfo) handler.unmarshal((Element) nodeList
					.elementAt(0)));
		}

		nodeList = XMLUtils.getChildElementsByTagName(element,
				SubscriptionHandler.TAG_NAME);
		for (int i = 0; i < nodeList.size(); i++) {
			handler = maker.lookup(SubscriptionHandler.TAG_NAME);
			obj.addSubscription((Subscription) handler
					.unmarshal((Element) nodeList.elementAt(i)));
		}

		return obj;
	}

	public void marshal(RegistryObject object, Element parent) {
		SaveSubscription request = (SaveSubscription) object;
		Element element = parent.getOwnerDocument().createElementNS(null,
				TAG_NAME);
		AbstractHandler handler = null;

		String generic = request.getGeneric();
		if (generic != null)
			element.setAttribute("generic", generic);

		AuthInfo authInfo = request.getAuthInfo();
		if (authInfo != null) {
			handler = maker.lookup(AuthInfoHandler.TAG_NAME);
			handler.marshal(authInfo, element);
		}

		Vector subscriptionVector = request.getSubscriptionVector();
		if ((subscriptionVector != null) && (subscriptionVector.size() > 0)) {
			handler = maker.lookup(SubscriptionHandler.TAG_NAME);
			for (int i = 0; i < subscriptionVector.size(); i++)
				handler.marshal((Subscription) subscriptionVector.elementAt(i),
						element);
		}

		parent.appendChild(element);
	}

	/** ************************************************************************ */
	/** *************************** TEST DRIVER ******************************** */
	/** ************************************************************************ */

	public static void main(String args[]) throws Exception {
		HandlerMaker maker = HandlerMaker.getInstance();
		AbstractHandler handler = maker
				.lookup(SaveSubscriptionHandler.TAG_NAME);

		Element parent = XMLUtils.newRootElement();
		Element child = null;

		AuthInfo authInfo = new AuthInfo();
		authInfo.setValue("6f157513-844e-4a95-a856-d257e6ba9726");

		Subscription subscription = new Subscription();
		subscription
				.setSubscriptionKey("uuid:269855db-62eb-4862-8e5a-1b06f2753038");

		SaveSubscription request = new SaveSubscription();
		request.setAuthInfo(authInfo);
		request.addSubscription(subscription);
		request.addSubscription(subscription);

		System.out.println();

		RegistryObject regObject = request;
		handler.marshal(regObject, parent);
		child = (Element) parent.getFirstChild();
		parent.removeChild(child);
		XMLUtils.writeXML(child, System.out);

		System.out.println();

		regObject = handler.unmarshal(child);
		handler.marshal(regObject, parent);
		child = (Element) parent.getFirstChild();
		parent.removeChild(child);
		XMLUtils.writeXML(child, System.out);
	}
}