/*
 * Copyright 2001-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;


import org.apache.juddi.datatype.business.BusinessEntity;
import org.apache.juddi.util.Config;
import org.apache.juddi.uuidgen.UUIDGen;
import org.apache.juddi.uuidgen.UUIDGenFactory;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Steve Viens (sviens@apache.org)
 */
class TestBusinessEntityTable {


	public TestBusinessEntityTable () {
		// make sure we're using a DBCP DataSource and
		// not trying to use JNDI to aquire one.
		Config.setStringProperty("juddi.useConnectionPool", "true");

		DHTHandler conn = null;
		try {

				conn = Database.aquireConnection();

			try {
				test(conn);
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		} finally {
			if (conn != null)
				try {
					conn.leave();
				} catch (RemoteException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
		}
	}

	public static void test(DHTHandler connection) throws Exception {

		UUIDGen uuidgen = UUIDGenFactory.getUUIDGen();

		try {
			String businessKey = uuidgen.uuidgen();
			BusinessEntity business = new BusinessEntity();
			business.setBusinessKey(businessKey);
			business.setAuthorizedName("Steve Viens");
			business.setOperator("www.jUDDI.org");

			String publisherID = "sviens";



			// insert a new BusinessEntity
			BusinessEntityTable.insert(business, publisherID, connection);

			// select one of the BusinessEntity objects
			business = BusinessEntityTable.select(businessKey, connection);

			// delete that BusinessEntity object
			 BusinessEntityTable.delete(businessKey,connection);

			// re-select that BusinessEntity object
			business = BusinessEntityTable.select(businessKey, connection);


		} catch (Exception ex) {

			throw ex;
		}
	}
}
