/*
 * Copyright 2001-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Vector;

import org.apache.juddi.datatype.KeyedReference;
import org.apache.juddi.datatype.business.BusinessEntity;
import org.apache.juddi.util.Config;
import org.apache.juddi.uuidgen.UUIDGen;
import org.apache.juddi.uuidgen.UUIDGenFactory;

import dermi.DHTHandler;

/**
 * @author Steve Viens (sviens@apache.org)
 */
class TestBusinessIdentifierTable {
	public static void main(String[] args) throws Exception {
		// make sure we're using a DBCP DataSource and
		// not trying to use JNDI to aquire one.
		Config.setStringProperty("juddi.useConnectionPool", "true");

		DHTHandler conn = null;
		try {
			conn = Database.aquireConnection();
			test(conn);
		} finally {
			if (conn != null)
				conn.leave();
		}
	}

	public static void test(DHTHandler connection) throws Exception {

		UUIDGen uuidgen = UUIDGenFactory.getUUIDGen();

		if (connection != null) {
			try {
				String businessKey = uuidgen.uuidgen();
				BusinessEntity business = new BusinessEntity();
				business.setBusinessKey(businessKey);
				business.setAuthorizedName("sviens");
				business.setOperator("WebServiceRegistry.com");

				Vector keyRefs = new Vector();
				keyRefs.add(new KeyedReference(uuidgen.uuidgen(),
						"blah, blah, blah"));
				keyRefs.add(new KeyedReference(uuidgen.uuidgen(),
						"Yadda, Yadda, Yadda"));
				keyRefs.add(new KeyedReference(uuidgen.uuidgen(),
						"WhoobWhoobWhoobWhoob"));
				keyRefs.add(new KeyedReference(uuidgen.uuidgen(),
						"Haachachachacha"));

				String authorizedUserID = "sviens";


				// insert a new BusinessEntity
				BusinessEntityTable.insert(business, authorizedUserID,
						connection);

				// insert a Collection of new Identifier KeyedReference objects
				BusinessIdentifierTable
						.insert(businessKey, keyRefs, connection);

				// insert another new BusinessEntity
				business.setBusinessKey(uuidgen.uuidgen());
				BusinessEntityTable.insert(business, authorizedUserID,
						connection);

				// insert another Collection of new Identifier KeyedReference
				// objects
				BusinessIdentifierTable.insert(business.getBusinessKey(),
						keyRefs, connection);

				// select a Collection of Identifier KeyedReference objects
				keyRefs = BusinessIdentifierTable.select(businessKey,
						connection);

				// delete a Collection of Identifier KeyedReference objects
				BusinessIdentifierTable.delete(businessKey, connection);

				// re-select a Collection of Identifier KeyedReference objects
				keyRefs = BusinessIdentifierTable.select(businessKey,
						connection);


			} catch (Exception ex) {

				throw ex;
			}
		}
	}
}
