/*
 * Copyright 2001-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Vector;

import org.apache.juddi.datatype.KeyedReference;
import org.apache.juddi.datatype.OverviewDoc;
import org.apache.juddi.datatype.tmodel.TModel;
import org.apache.juddi.util.Config;
import org.apache.juddi.uuidgen.UUIDGen;
import org.apache.juddi.uuidgen.UUIDGenFactory;

import dermi.DHTHandler;

/**
 * @author Steve Viens (sviens@apache.org)
 */
class TestTModelIdentifierTable {
	public static void main(String[] args) throws Exception {
		// make sure we're using a DBCP DataSource and
		// not trying to use JNDI to aquire one.
		Config.setStringProperty("juddi.useConnectionPool", "true");

		DHTHandler conn = null;
		try {
			conn = Database.aquireConnection();
			test(conn);
		} finally {
			if (conn != null)
				conn.leave();
		}
	}

	public static void test(DHTHandler connection) throws Exception {

		UUIDGen uuidgen = UUIDGenFactory.getUUIDGen();

		if (connection != null) {
			try {
				OverviewDoc overviewDoc = new OverviewDoc();
				overviewDoc
						.setOverviewURL("http://www.steveviens.com/overviewdoc.html");

				String tModelKey = uuidgen.uuidgen();
				TModel tModel = new TModel();
				tModel.setTModelKey(tModelKey);
				tModel.setAuthorizedName("sviens");
				tModel.setOperator("WebServiceRegistry.com");
				tModel.setName("Tuscany Web Service Company");
				tModel.setOverviewDoc(overviewDoc);

				Vector keyRefs = new Vector();
				keyRefs.add(new KeyedReference(uuidgen.uuidgen(),
						"blah, blah, blah"));
				keyRefs.add(new KeyedReference(uuidgen.uuidgen(),
						"Yadda, Yadda, Yadda"));
				keyRefs.add(new KeyedReference(uuidgen.uuidgen(),
						"WhoobWhoobWhoobWhoob"));
				keyRefs.add(new KeyedReference(uuidgen.uuidgen(),
						"Haachachachacha"));

				String authorizedUserID = "sviens";



				// insert a new TModel
				TModelTable.insert(tModel, authorizedUserID, connection);

				// insert a Collection of new Identifier KeyedReference objects
				TModelIdentifierTable.insert(tModelKey, keyRefs, connection);

				// insert another new TModel
				tModel.setTModelKey(uuidgen.uuidgen());
				TModelTable.insert(tModel, authorizedUserID, connection);

				// insert another Collection of new Identifier KeyedReference
				// objects
				TModelIdentifierTable.insert(tModel.getTModelKey(), keyRefs,
						connection);

				// select a Collection of Identifier KeyedReference objects
				keyRefs = TModelIdentifierTable.select(tModelKey, connection);

				// delete a Collection of Identifier KeyedReference objects
				TModelIdentifierTable.delete(tModelKey, connection);

				// re-select a Collection of Identifier KeyedReference objects
				keyRefs = TModelIdentifierTable.select(tModelKey, connection);


			} catch (Exception ex) {

				throw ex;
			}
		}
	}
}
