/*
 * Copyright 2001-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.jdbc;

import java.sql.Connection;
import java.util.Vector;

import org.apache.juddi.datatype.Description;
import org.apache.juddi.datatype.binding.AccessPoint;
import org.apache.juddi.datatype.binding.BindingTemplate;
import org.apache.juddi.datatype.business.BusinessEntity;
import org.apache.juddi.datatype.service.BusinessService;
import org.apache.juddi.util.Config;
import org.apache.juddi.util.jdbc.Transaction;
import org.apache.juddi.uuidgen.UUIDGen;
import org.apache.juddi.uuidgen.UUIDGenFactory;

/**
 * @author Steve Viens (sviens@apache.org)
 */
class TestBindingDescTable {
	public static void main(String[] args) throws Exception {
		// make sure we're using a DBCP DataSource and
		// not trying to use JNDI to aquire one.
		Config.setStringProperty("juddi.useConnectionPool", "true");

		Connection conn = null;
		try {
			conn = Database.aquireConnection();
			test(conn);
		} finally {
			if (conn != null)
				conn.close();
		}
	}

	public static void test(Connection connection) throws Exception {
		Transaction txn = new Transaction();
		UUIDGen uuidgen = UUIDGenFactory.getUUIDGen();

		if (connection != null) {
			try {
				// BusinessKey businessKey = BusinessKey.createKey();
				String businessKey = uuidgen.uuidgen();
				BusinessEntity business = new BusinessEntity();
				business.setBusinessKey(businessKey);
				business.setAuthorizedName("sviens");
				business.setOperator("WebServiceRegistry.com");

				// ServiceKey serviceKey = ServiceKey.createKey();
				String serviceKey = uuidgen.uuidgen();
				BusinessService service = new BusinessService();
				service.setServiceKey(serviceKey);
				service.setBusinessKey(businessKey);

				// BindingKey bindingKey = BindingKey.createKey();
				String bindingKey = uuidgen.uuidgen();
				BindingTemplate binding = new BindingTemplate();
				binding.setAccessPoint(new AccessPoint(
						"http://www.juddi.org/binding.html", "http"));
				binding.setHostingRedirector(null);
				binding.setBindingKey(bindingKey);
				binding.setServiceKey(serviceKey);

				Vector descList = new Vector();
				descList.add(new Description("blah, blah, blah", "en"));
				descList.add(new Description("Yadda, Yadda, Yadda", "it"));
				descList.add(new Description("WhoobWhoobWhoobWhoob", "cy"));
				descList.add(new Description("Haachachachacha", "km"));

				String authorizedUserID = "sviens";

				// begin a new transaction
				txn.begin(connection);

				// insert a new BusinessEntity
				BusinessEntityTable.insert(business, authorizedUserID,
						connection);

				// insert a new BusinessService
				BusinessServiceTable.insert(service, connection);

				// insert a new BindingTemplate
				BindingTemplateTable.insert(binding, connection);

				// insert a Collection of Description objects
				BindingDescTable.insert(bindingKey, descList, connection);

				// select the Collection of Description objects
				descList = BindingDescTable.select(bindingKey, connection);

				// delete the Collection of Description objects
				BindingDescTable.delete(bindingKey, connection);

				// select the Collection of Description objects
				descList = BindingDescTable.select(bindingKey, connection);

				// commit the transaction
				txn.commit();
			} catch (Exception ex) {
				try {
					txn.rollback();
				} catch (java.sql.SQLException sqlex) {
					sqlex.printStackTrace();
				}
				throw ex;
			}
		}
	}
}
