/*
 * Copyright 2001-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.jdbc;

import java.sql.Connection;
import java.util.Vector;

import org.apache.juddi.datatype.Description;
import org.apache.juddi.datatype.binding.AccessPoint;
import org.apache.juddi.datatype.binding.BindingTemplate;
import org.apache.juddi.datatype.binding.TModelInstanceInfo;
import org.apache.juddi.datatype.business.BusinessEntity;
import org.apache.juddi.datatype.service.BusinessService;
import org.apache.juddi.util.Config;
import org.apache.juddi.util.jdbc.Transaction;
import org.apache.juddi.uuidgen.UUIDGen;
import org.apache.juddi.uuidgen.UUIDGenFactory;

/**
 * @author Steve Viens (sviens@apache.org)
 */
class TestTModelInstanceInfoDescTable {
	public static void main(String[] args) throws Exception {
		// make sure we're using a DBCP DataSource and
		// not trying to use JNDI to aquire one.
		Config.setStringProperty("juddi.useConnectionPool", "true");

		Connection conn = null;
		try {
			conn = Database.aquireConnection();
			test(conn);
		} finally {
			if (conn != null)
				conn.close();
		}
	}

	public static void test(Connection connection) throws Exception {
		Transaction txn = new Transaction();
		UUIDGen uuidgen = UUIDGenFactory.getUUIDGen();

		if (connection != null) {
			try {
				String businessKey = uuidgen.uuidgen();
				BusinessEntity business = new BusinessEntity();
				business.setBusinessKey(businessKey);
				business.setAuthorizedName("sviens");
				business.setOperator("WebServiceRegistry.com");

				String serviceKey = uuidgen.uuidgen();
				BusinessService service = new BusinessService();
				service.setBusinessKey(businessKey);
				service.setServiceKey(serviceKey);

				String bindingKey = uuidgen.uuidgen();
				BindingTemplate binding = new BindingTemplate();
				binding.setServiceKey(serviceKey);
				binding.setBindingKey(bindingKey);
				binding.setAccessPoint(new AccessPoint(
						"http://www.juddi.org/bindingtemplate.html", "http"));

				Vector infoList = new Vector();
				infoList.add(new TModelInstanceInfo(uuidgen.uuidgen()));
				int infoID = 0;

				Vector descList = new Vector();
				descList.add(new Description("blah, blah, blah", "en"));
				descList.add(new Description("Yadda, Yadda, Yadda", "it"));
				descList.add(new Description("WhoobWhoobWhoobWhoob", "cy"));
				descList.add(new Description("Haachachachacha", "km"));

				String authorizedUserID = "sviens";

				// begin a new transaction
				txn.begin(connection);

				// insert a new BusinessEntity
				BusinessEntityTable.insert(business, authorizedUserID,
						connection);

				// insert a new BusinessService
				BusinessServiceTable.insert(service, connection);

				// insert a new BindingTemplate
				BindingTemplateTable.insert(binding, connection);

				// insert a Collection of TModelInstanceInfo objects
				TModelInstanceInfoTable
						.insert(bindingKey, infoList, connection);

				// insert a Collection of Description objects
				TModelInstanceInfoDescTable.insert(bindingKey, infoID,
						descList, connection);

				// select a Collection of Description objects (by BindingKey)
				descList = TModelInstanceInfoDescTable.select(bindingKey,
						infoID, connection);

				// delete a Collection of Description objects (by BindingKey)
				TModelInstanceInfoDescTable.delete(bindingKey, connection);

				// re-select a Collection of Description objects (by BindingKey)
				descList = TModelInstanceInfoDescTable.select(bindingKey,
						infoID, connection);

				// commit the transaction
				txn.commit();
			} catch (Exception ex) {
				try {
					txn.rollback();
				} catch (java.sql.SQLException sqlex) {
					sqlex.printStackTrace();
				}
				throw ex;
			}
		}
	}
}
