/*
 * Copyright 2001-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.handler;

import org.apache.juddi.datatype.RegistryObject;
import org.apache.juddi.datatype.publisher.PublisherID;
import org.apache.juddi.util.xml.XMLUtils;
import org.w3c.dom.Element;

/**
 * @author anou_mana@apache.org
 */
public class PublisherIDHandlerTests extends HandlerTestCase {
	private static final String TEST_ID = "juddi.handler.DeletePublisherID.test";

	private PublisherIDHandler handler = null;

	public PublisherIDHandlerTests(String arg0) {
		super(arg0);
	}

	public static void main(String[] args) {
		junit.textui.TestRunner.run(PublisherIDHandlerTests.class);
	}

	public void setUp() {
		HandlerMaker maker = HandlerMaker.getInstance();
		handler = (PublisherIDHandler) maker
				.lookup(PublisherIDHandler.TAG_NAME);
	}

	private RegistryObject getRegistryObject() {
		PublisherID object = new PublisherID();
		object.setValue("guest");

		return object;

	}

	private Element getMarshalledElement(RegistryObject regObject) {
		Element parent = XMLUtils.newRootElement();
		Element child = null;

		if (regObject == null)
			regObject = this.getRegistryObject();

		handler.marshal(regObject, parent);
		child = (Element) parent.getFirstChild();
		parent.removeChild(child);

		return child;
	}

	public void testMarshal() {
		Element child = getMarshalledElement(null);

		String marshalledString = this.getXMLString(child);

		assertNotNull("Marshalled  PublisherID ", marshalledString);

	}

	public void testUnMarshal() {

		Element child = getMarshalledElement(null);
		RegistryObject regObject = handler.unmarshal(child);

		assertNotNull("UnMarshalled  PublisherID ", regObject);

	}

	public void testMarshUnMarshal() {
		Element child = getMarshalledElement(null);

		String marshalledString = this.getXMLString(child);

		assertNotNull("Marshalled  PublisherID ", marshalledString);

		RegistryObject regObject = handler.unmarshal(child);

		child = getMarshalledElement(regObject);

		String unMarshalledString = this.getXMLString(child);

		assertNotNull("Unmarshalled  PublisherID ", unMarshalledString);

		boolean equals = marshalledString.equals(unMarshalledString);

		assertEquals("Expected result: ", marshalledString, unMarshalledString);
	}

}
